.. _core_module:

:mod:`cubicweb.pyramid.core`
----------------------------

.. automodule:: cubicweb.pyramid.core

    .. autofunction:: includeme

    .. autofunction:: cw_to_pyramid

    .. autofunction:: render_view

    .. autofunction:: repo_connect
    .. autofunction:: get_principals

    .. autoclass:: CubicWebPyramidRequest
        :show-inheritance:
        :members:

    .. autofunction:: _cw_session
    .. autofunction:: _cw_cnx
    .. autofunction:: _cw_request
